#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef HAVE_SENDFILE
#undef HAVE_SYS_SENDFILE_H
#undef PACKAGE_LOCALE_DIR
#undef PACKAGE_DATA_DIR
#undef PACKAGE_SOURCE_DIR
#undef HAVE_CTYPE_H
#undef USE_SEARCH_XML
#undef USE_GTK2
#undef USE_REMOTE_SHELL
